@@ -6,9 +6,9 @@
 #include "mockdecoration.h"
 #include "mockbridge.h"
 
-#include <utility>
 #include <QMap>
 #include <QVariantMap>
+#include <utility>
 
 MockDecoration::MockDecoration(QObject *parent, const QVariantList &args)
     : Decoration(parent, args)
@@ -16,7 +16,8 @@ MockDecoration::MockDecoration(QObject *parent, const QVariantList &args)
 }
 
 #ifdef _MSC_VER
-QMap<QString, QVariant> makeMap(const QString& key, const QVariant &value) {
+QMap<QString, QVariant> makeMap(const QString &key, const QVariant &value)
+{
     QMap<QString, QVariant> ret;
     ret.insert(key, value);
     return ret;
@@ -28,9 +29,21 @@ MockDecoration::MockDecoration(MockBridge *bridge)
     : MockDecoration(nullptr, QVariantList({QVariantMap({{QStringLiteral("bridge"), QVariant::fromValue(bridge)}})}))
 #endif
 {
+    create();
+    init();
+
+    apply(nextState()->clone());
+    connect(this, &MockDecoration::nextStateChanged, this, [this]() {
+        apply(nextState()->clone());
+    });
 }
 
-void MockDecoration::paint(QPainter *painter, const QRect &repaintRegion)
+bool MockDecoration::init()
+{
+    return true;
+}
+
+void MockDecoration::paint(QPainter *painter, const QRectF &repaintRegion)
 {
     Q_UNUSED(painter)
     Q_UNUSED(repaintRegion)
@@ -50,3 +63,5 @@ void MockDecoration::setTitleBar(const QRect &rect)
 {
     Decoration::setTitleBar(rect);
 }
+
+#include "moc_mockdecoration.cpp"
